@@ -16,6 +16,7 @@ from payloop._providers import Anthropic as LlmProviderAnthropic
 from payloop._providers import Google as LlmProviderGoogle
 from payloop._providers import LangChain as LlmProviderLangChain
 from payloop._providers import OpenAi as LlmProviderOpenAi
+from payloop._providers import PydanticAi as LlmProviderPydanticAi
 
 __all__ = ["Payloop"]
 
@@ -27,7 +28,7 @@ class Payloop:
 
         if api_key is None:
             raise RuntimeError(
-                "API key is missing. Either set the PAYLOOP_API_KEY environment\n"
+                "API key is missing. Either set the PAYLOOP_API_KEY environment "
                 + "variable or set the api_key parameter when instantiating Payloop."
             )
 
@@ -39,6 +40,7 @@ class Payloop:
         self.google = LlmProviderGoogle(self)
         self.langchain = LlmProviderLangChain(self)
         self.openai = LlmProviderOpenAi(self)
+        self.pydantic_ai = LlmProviderPydanticAi(self)
 
     def attribution(
         self,
