@@ -67,6 +67,9 @@ class LangChain(BaseClient):
     CLIENT_PROVIDER = "langchain"
 
     def register(self, chatopenai=None, chatvertexai=None):
+        if chatopenai is None and chatvertexai is None:
+            raise RuntimeError("LangChain::register called without client")
+
         if chatopenai is not None:
             if not hasattr(chatopenai, "client"):
                 raise RuntimeError("client provided is not instance of ChatOpenAI")
@@ -87,7 +90,8 @@ class LangChain(BaseClient):
                 chatopenai.client._client._payloop_installed = True
 
             self.client = chatopenai.client._client
-        elif chatvertexai is not None:
+
+        if chatvertexai is not None:
             if not hasattr(chatvertexai, "prediction_client"):
                 raise RuntimeError("client provided isnot instance of ChatVertexAI")
 
@@ -108,8 +112,6 @@ class LangChain(BaseClient):
                 chatvertexai.prediction_client._payloop_installed = True
 
             self.client = chatvertexai.prediction_client
-        else:
-            raise RuntimeError("LangChain::register called without client")
 
         return self
 
