@@ -11,6 +11,7 @@ from payloop._clients import Anthropic as AnthropicPayloopClient
 from payloop._clients import Google as GooglePayloopClient
 from payloop._clients import LangChain as LangChainPayloopClient
 from payloop._clients import OpenAi as OpenAiPayloopClient
+from payloop._clients import PydanticAi as PydanticAiPayloopClient
 
 
 class Anthropic(BaseProvider):
@@ -40,8 +41,18 @@ class LangChain(BaseProvider):
 
 
 class OpenAi(BaseProvider):
-    def register(self, client):
+    def register(self, client, stream=False):
         if self.client is None:
-            self.client = OpenAiPayloopClient(self.config).register(client)
+            self.client = OpenAiPayloopClient(self.config).register(
+                client, stream=stream
+            )
+
+        return self.parent
+
+
+class PydanticAi(BaseProvider):
+    def register(self, client):
+        if self.client is None:
+            self.client = PydanticAiPayloopClient(self.config).register(client)
 
         return self.parent
